package fishrungames.bashgid.core.db;

import java.util.ArrayList;
import java.util.Locale;

import fishrungames.bashgid.MainActivity;
import fishrungames.bashgid.core.AlbumManager;
import fishrungames.bashgid.core.AlbumManager.AlbumFullData;
import fishrungames.bashgid.core.AlbumManager.AlbumRecordData;
import fishrungames.bashgid.core.AlbumManager.AlbumShortData;
import fishrungames.bashgid.core.TranslationManager.TranslationRecordData;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;

import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

public class TranslationDataSource
{

	private BashgidSqliteHelper dbHelper = null;

	public TranslationDataSource(Context context, BashgidSqliteHelper dbHelper)
	{
		this.dbHelper = dbHelper;

	}

	public void CreateNewTranslation(TranslationRecordData recordData)
	{
		SQLiteDatabase database = dbHelper.getWritableDatabase();

		if (database != null)
		{

			try
			{
				ContentValues values = new ContentValues();

				values.put(BashgidSqliteHelper.COLUMN_NAME, recordData.name);
				values.put(BashgidSqliteHelper.COLUMN_TEXT_EN, recordData.textEn);
				values.put(BashgidSqliteHelper.COLUMN_TEXT_RU, recordData.textRu);
				values.put(BashgidSqliteHelper.COLUMN_TEXT_ZH, recordData.textZh);
				
				if (!innerIsTranslationAlreadyExist(recordData.name, database))
				{
					database.insert(BashgidSqliteHelper.TABLE_TRANSLATION, null, values);
				} else
				{
					database.update(BashgidSqliteHelper.TABLE_TRANSLATION, values, BashgidSqliteHelper.COLUMN_NAME + " = " +"\"" + recordData.name +"\"", null);
				}

			} finally
			{
				dbHelper.close();
			}
		}

	}
	
	public String TryTranslateText(String name, SQLiteDatabase database)
	{
		if (innerIsTranslationAlreadyExist(name, database))
		{
			TranslationRecordData record = innerGetTranslationByName(name, database);
			
			if (Locale.getDefault().equals(new Locale("ru")))
			{
				return record.textRu;
			}
			else if (Locale.getDefault() == Locale.CHINA)
			{
				return record.textZh;
			}
			
			return record.textEn;
		}
		else
		{
			return name;
		}
	}
/*
	public boolean IsTranslationAlreadyExist(String name)
	{
		boolean result = false;

		SQLiteDatabase database = dbHelper.getWritableDatabase();

		if (database != null)
		{

			try
			{
				result = innerIsAlbumAlreadyExist(name, database);

			} finally
			{
				dbHelper.close();
			}
		}

		return result;

	}*/
/*
	public void AddPhotoToAlbum(String imageUrl, String albumName)
	{
		SQLiteDatabase database = dbHelper.getWritableDatabase();

		if (database != null)
		{

			try
			{
				ContentValues values = new ContentValues();

				values.put(BashgidSqliteHelper.COLUMN_IMAGE_URL, imageUrl);
				values.put(BashgidSqliteHelper.COLUMN_NAME, albumName);

				if (!innerPhotoAlbumRelationAlreadyExist(imageUrl, albumName, database))
				{
					Log.e("a", "aaa1");
					database.insert(BashgidSqliteHelper.TABLE_PHOTO_ALBUM_RELATION, null, values);
					Log.e("a", "aaa2");
				}
				Log.e("a", "aaa3");

			} finally
			{
				dbHelper.close();
			}
		}
	}
*/
	
	public TranslationRecordData GetTranslationRecordData(String name)
	{
		TranslationRecordData result = null;

		SQLiteDatabase database = dbHelper.getWritableDatabase();

		if (database != null)
		{
			try
			{

				result = innerGetTranslationByName(name, database);


			} finally
			{
				dbHelper.close();
			}
		}

		return result;
	}
	
	/*
	public AlbumFullData GetAlbumFullData(String name)
	{
		AlbumFullData result = null;

		SQLiteDatabase database = dbHelper.getWritableDatabase();

		if (database != null)
		{
			try
			{

				result = InnerGetAlbumFullData(name, database);

			} finally
			{
				dbHelper.close();
			}
		}

		return result;
	}

	public AlbumFullData InnerGetAlbumFullData(String name, SQLiteDatabase database)
	{

		AlbumFullData result = null;

		AlbumRecordData recordData = innerGetAlbumByName(name, database);

		if (recordData != null)
		{

			result = new AlbumFullData(recordData);

			ArrayList<String> imageUrlArr = innerGetImageUrlArrInAlbum(name, database);

			for (String imageUrl : imageUrlArr)
			{
				result.photoRecordArr.add(MainActivity.getInstance().photoDataSource.InnerGetPhotoByImageUrl(imageUrl, database));
			}

		}

		return result;
	}

	public AlbumShortData GetAlbumShortData(String name)
	{
		AlbumShortData result = null;

		SQLiteDatabase database = dbHelper.getWritableDatabase();

		if (database != null)
		{
			try
			{

				AlbumRecordData recordData = innerGetAlbumByName(name, database);

				if (recordData != null)
				{

					result = new AlbumShortData(recordData);

					ArrayList<String> imageUrlArr = innerGetImageUrlArrInAlbum(name, database);

					result.photoCount = imageUrlArr.size();

					if (imageUrlArr.size() > 0)
					{
						result.firstImageUrl = imageUrlArr.get(0);
					}
				}

			} finally
			{
				dbHelper.close();
			}
		}

		return result;
	}

	public ArrayList<AlbumShortData> GetAllAlbumShortData()
	{

		ArrayList<AlbumShortData> result = new ArrayList<AlbumShortData>();

		SQLiteDatabase database = dbHelper.getWritableDatabase();

		if (database != null)
		{
			try
			{

				Cursor cursor = database.query(BashgidSqliteHelper.TABLE_ALBUM, new String[] { BashgidSqliteHelper.COLUMN_NAME,
						BashgidSqliteHelper.COLUMN_TITLE, BashgidSqliteHelper.COLUMN_DESCRIPTION }, null, null, null, null, null, null);

				if (cursor != null)
				{
					if (cursor.moveToFirst())
					{
						do
						{

							AlbumShortData shortData = new AlbumShortData(new AlbumRecordData(cursor.getString(0), cursor.getString(1), cursor.getString(2)));

							ArrayList<String> imageUrlArr = innerGetImageUrlArrInAlbum(shortData.name, database);

							shortData.photoCount = imageUrlArr.size();

							if (imageUrlArr.size() > 0)
							{
								shortData.firstImageUrl = imageUrlArr.get(0);
							}

							result.add(shortData);
						} while (cursor.moveToNext());

					}
					
					cursor.close();
				}

			} finally
			{
				dbHelper.close();
			}

		}

		return result;
	}
*/
	private boolean innerIsTranslationAlreadyExist(String name, SQLiteDatabase database)
	{
		boolean result = false;
		
		Cursor cursor = database.query(BashgidSqliteHelper.TABLE_TRANSLATION, new String[] { BashgidSqliteHelper.COLUMN_NAME }, BashgidSqliteHelper.COLUMN_NAME
				+ "=?", new String[] { name }, null, null, null, null);

		if (cursor != null)
		{
			if (cursor.getCount() > 0)
			{
				result = true;
			}
			
			cursor.close();
			cursor = null;
			
			
		}

		return result;

	}
/*
	private boolean innerPhotoAlbumRelationAlreadyExist(String imageUrl, String name, SQLiteDatabase database)
	{
		boolean result = false;
		
		Cursor cursor = database.query(BashgidSqliteHelper.TABLE_PHOTO_ALBUM_RELATION, new String[] { BashgidSqliteHelper.COLUMN_IMAGE_URL,
				BashgidSqliteHelper.COLUMN_NAME }, BashgidSqliteHelper.COLUMN_IMAGE_URL + "=?" + " AND " + BashgidSqliteHelper.COLUMN_NAME + "=?",
				new String[] { imageUrl, name }, null, null, null, null);

		if (cursor != null)
		{
			if (cursor.getCount() > 0)
			{
				result = true;
			}
			
			cursor.close();
		}

		return result;

	}

	private ArrayList<String> innerGetImageUrlArrInAlbum(String name, SQLiteDatabase database)
	{
		ArrayList<String> result = new ArrayList<String>();

		Cursor cursor = database.query(BashgidSqliteHelper.TABLE_PHOTO_ALBUM_RELATION, new String[] { BashgidSqliteHelper.COLUMN_IMAGE_URL },
				BashgidSqliteHelper.COLUMN_NAME + "=?", new String[] { name }, null, null, null, null);

		if (cursor != null)
		{
			if (cursor.moveToFirst())
			{
				do
				{
					result.add(cursor.getString(0));
				} while (cursor.moveToNext());

			}
			
			cursor.close();
		}

		return result;

	}

*/
	public TranslationRecordData innerGetTranslationByName(String name, SQLiteDatabase database)
	{
		
		TranslationRecordData result = null;

		Cursor cursor = database.query(BashgidSqliteHelper.TABLE_TRANSLATION, new String[] { BashgidSqliteHelper.COLUMN_NAME, BashgidSqliteHelper.COLUMN_TEXT_EN,
				BashgidSqliteHelper.COLUMN_TEXT_RU, BashgidSqliteHelper.COLUMN_TEXT_ZH }, BashgidSqliteHelper.COLUMN_NAME + "=?", new String[] { name }, null, null, null, null);

		if (cursor != null)
		{
			if (cursor.moveToFirst())
			{
				result = new TranslationRecordData(cursor.getString(0), cursor.getString(1), cursor.getString(2), cursor.getString(3));
			}
			
			cursor.close();
			cursor = null;
		}

		return result;

	}
	
	
	

}
